@@ -1,16 +1,17 @@
 import string
 
 from auto_labeling_pipeline.models import RequestModelFactory
-from django.db import models
-from django.dispatch import receiver
-from django.db.models.signals import post_save, pre_delete
-from django.urls import reverse
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.exceptions import ValidationError
+from django.db import models
+from django.db.models.signals import m2m_changed, post_save, pre_delete
+from django.dispatch import receiver
+from django.urls import reverse
 from polymorphic.models import PolymorphicModel
 
-from .managers import AnnotationManager, Seq2seqAnnotationManager
+from .managers import (AnnotationManager, RoleMappingManager,
+                       Seq2seqAnnotationManager)
 
 DOCUMENT_CLASSIFICATION = 'DocumentClassification'
 SEQUENCE_LABELING = 'SequenceLabeling'
@@ -27,7 +28,7 @@ PROJECT_CHOICES = (
 class Project(PolymorphicModel):
     name = models.CharField(max_length=100)
     description = models.TextField(default='')
-    guideline = models.TextField(default='')
+    guideline = models.TextField(default='', blank=True)
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
     users = models.ManyToManyField(User, related_name='projects')
@@ -205,6 +206,10 @@ class Document(models.Model):
     def __str__(self):
         return self.text[:50]
 
+    @property
+    def comment_count(self):
+        return Comment.objects.filter(document=self.id).count()
+
 
 class Comment(models.Model):
     text = models.TextField()
@@ -213,6 +218,17 @@ class Comment(models.Model):
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
 
+    @property
+    def username(self):
+        return self.user.username
+
+    @property
+    def document_text(self):
+        return self.document.text
+
+    class Meta:
+        ordering = ('-created_at', )
+
 
 class Annotation(models.Model):
     objects = AnnotationManager()
@@ -284,6 +300,7 @@ class RoleMapping(models.Model):
     role = models.ForeignKey(Role, on_delete=models.CASCADE)
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
+    objects = RoleMappingManager()
 
     def clean(self):
         other_rolemappings = self.project.role_mappings.exclude(id=self.id)
@@ -292,7 +309,7 @@ class RoleMapping(models.Model):
             raise ValidationError('This user is already assigned to a role in this project.')
 
     class Meta:
-        unique_together = ("user", "project", "role")
+        unique_together = ("user", "project")
 
 
 @receiver(post_save, sender=RoleMapping)
@@ -308,33 +325,48 @@ def add_linked_project(sender, instance, created, **kwargs):
         user.save()
 
 
-@receiver(post_save)
-def add_superusers_to_project(sender, instance, created, **kwargs):
-    if not created:
-        return
-    if sender not in Project.__subclasses__():
-        return
-    superusers = User.objects.filter(is_superuser=True)
-    admin_role = Role.objects.filter(name=settings.ROLE_PROJECT_ADMIN).first()
-    if superusers and admin_role:
+# @receiver(post_save)
+# def add_superusers_to_project(sender, instance, created, **kwargs):
+#     if not created:
+#         return
+#     if sender not in Project.__subclasses__():
+#         return
+#     superusers = User.objects.filter(is_superuser=True)
+#     admin_role = Role.objects.filter(name=settings.ROLE_PROJECT_ADMIN).first()
+#     if superusers and admin_role:
+#         RoleMapping.objects.bulk_create(
+#             [RoleMapping(role_id=admin_role.id, user_id=superuser.id, project_id=instance.id)
+#              for superuser in superusers]
+#         )
+#
+#
+# @receiver(post_save, sender=User)
+# def add_new_superuser_to_projects(sender, instance, created, **kwargs):
+#     if created and instance.is_superuser:
+#         admin_role = Role.objects.filter(name=settings.ROLE_PROJECT_ADMIN).first()
+#         projects = Project.objects.all()
+#         if admin_role and projects:
+#             RoleMapping.objects.bulk_create(
+#                 [RoleMapping(role_id=admin_role.id, user_id=instance.id, project_id=project.id)
+#                  for project in projects]
+#             )
+
+@receiver(m2m_changed, sender=Project.users.through)
+def remove_mapping_on_remove_user_from_project(sender, instance, action, reverse, **kwargs):
+    # if reverse is True, pk_set is project_ids and instance is user.
+    # else, pk_set is user_ids and instance is project.
+    user_ids = kwargs['pk_set']
+    if action.startswith('post_remove') and not reverse:
+        RoleMapping.objects.filter(user__in=user_ids, project=instance).delete()
+    elif action.startswith('post_add') and not reverse:
+        admin_role = Role.objects.get(name=settings.ROLE_PROJECT_ADMIN)
         RoleMapping.objects.bulk_create(
-            [RoleMapping(role_id=admin_role.id, user_id=superuser.id, project_id=instance.id)
-             for superuser in superusers]
+            [RoleMapping(role=admin_role, project=instance, user_id=user)
+             for user in user_ids
+             if not RoleMapping.objects.filter(project=instance, user_id=user).exists()]
         )
 
 
-@receiver(post_save, sender=User)
-def add_new_superuser_to_projects(sender, instance, created, **kwargs):
-    if created and instance.is_superuser:
-        admin_role = Role.objects.filter(name=settings.ROLE_PROJECT_ADMIN).first()
-        projects = Project.objects.all()
-        if admin_role and projects:
-            RoleMapping.objects.bulk_create(
-                [RoleMapping(role_id=admin_role.id, user_id=instance.id, project_id=project.id)
-                 for project in projects]
-            )
-
-
 @receiver(pre_delete, sender=RoleMapping)
 def delete_linked_project(sender, instance, using, **kwargs):
     userInstance = instance.user
