@@ -3,20 +3,21 @@ from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.shortcuts import get_object_or_404
 from rest_framework import serializers
-from rest_polymorphic.serializers import PolymorphicSerializer
 from rest_framework.exceptions import ValidationError
+from rest_polymorphic.serializers import PolymorphicSerializer
 
-
-from .models import Label, Project, Document, RoleMapping, Role, Comment, AutoLabelingConfig
-from .models import TextClassificationProject, SequenceLabelingProject, Seq2seqProject, Speech2textProject
-from .models import DocumentAnnotation, SequenceAnnotation, Seq2seqAnnotation, Speech2textAnnotation
+from .models import (AutoLabelingConfig, Comment, Document, DocumentAnnotation,
+                     Label, Project, Role, RoleMapping, Seq2seqAnnotation,
+                     Seq2seqProject, SequenceAnnotation,
+                     SequenceLabelingProject, Speech2textAnnotation,
+                     Speech2textProject, TextClassificationProject)
 
 
 class UserSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = get_user_model()
-        fields = ('id', 'username', 'first_name', 'last_name', 'email', 'is_superuser')
+        fields = ('id', 'username', 'is_superuser')
 
 
 class LabelSerializer(serializers.ModelSerializer):
@@ -61,16 +62,16 @@ class LabelSerializer(serializers.ModelSerializer):
 
 
 class CommentSerializer(serializers.ModelSerializer):
+
     class Meta:
         model = Comment
-        fields = ('id', 'text', 'user')
+        fields = ('id', 'user', 'username', 'document', 'document_text', 'text', 'created_at', )
         read_only_fields = ('user', 'document')
 
 
 class DocumentSerializer(serializers.ModelSerializer):
     annotations = serializers.SerializerMethodField()
     annotation_approver = serializers.SerializerMethodField()
-    comments = CommentSerializer(many=True, read_only=True)
 
     def get_annotations(self, instance):
         request = self.context.get('request')
@@ -90,7 +91,7 @@ class DocumentSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = Document
-        fields = ('id', 'text', 'annotations', 'meta', 'annotation_approver', 'comments')
+        fields = ('id', 'text', 'annotations', 'meta', 'annotation_approver', 'comment_count')
 
 
 class ApproverSerializer(DocumentSerializer):
